""" 
Python connector module for Node.JS applications

"""
__version__ = '1.0.3'

import json
import zmq
import threading


class Interface(threading.Thread):
    # create
    def __init__(self):
        self.port = 24001
        self.socket_address = 'tcp://127.0.0.1:%d' % self.port

        # publisher socket
        self.context = zmq.Context()
        self.socket = self.context.socket(zmq.REP)

        # routes
        self.router = {}

        # thread processing
        threading.Thread.__init__(self)
        self.setDaemon(True)

    # task processing
    def run(self):
        # infinite loop
        while(True):
            # query processing
            query = json.loads(self.socket.recv())

            # return registered handlers
            if(query['_p'] == '__pyroutes'):
                reply = [k for k in self.router]
                self.socket.send_json(
                    dict(_p=query['_p'], _id=query['_id'], data=reply))

            # check query path
            elif(query['_p'] in self.router):
                fn, ctx = self.router[query['_p']]
                args = {}
                if('args' in query):
                    args = query['args']

                # execute handler
                reply = fn(args, ctx)

                self.socket.send_json(
                    dict(_p=query['_p'], _id=query['_id'], data=reply))

    # routing queries

    def handle(self, path, handle, context={}):
        self.router[path] = (handle, context)

    # launch interface
    def listen(self, port=24001):
        self.port = int(port)
        self.socket_address = 'tcp://127.0.0.1:%d' % self.port
        self.socket.bind(self.socket_address)

        self.start()



import unittest

import nodeconnector


class TestMinimal(unittest.TestCase):
    """
    Arguments test
    """

    def test_arguments(self):
        api = nodeconnector.Interface()
        # default port
        self.assertTrue((api.socket_address == 'tcp://127.0.0.1:24001'))
        # custom port
        api.listen(8080)
        self.assertTrue((api.socket_address == 'tcp://127.0.0.1:8080'))
        # end socket
        # api.end()


if __name__ == '__main__':
    unittest.main()



"""Setuptools entry point."""
import codecs
import os

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

dirname = os.path.dirname(__file__)
readme_filename = os.path.join(dirname, 'README.rst')

description = 'Python connector module for Node.JS applications'
long_description = description
if os.path.exists(readme_filename):
    readme_content = codecs.open(readme_filename, encoding='utf-8').read()
    long_description = readme_content

setup(name='nodeconnector',
      version='1.0.3',
      description=description,
      long_description=long_description,
      long_description_content_type='text/x-rst',
      url='https://github.com/cristidbr/nodeconnector',
      author='Cristian Dobre',
      author_email='cristian.dobre@hbfsrobotics.com',
      license='MIT',
      packages=['nodeconnector'],
      install_requires=[
          'pyzmq',
      ],
      test_suite='nose.collector',
      tests_require=['nose'],
      zip_safe=False)